==> hls_player-1.0.3.tar.gz: ios/Classes/CustomAVPlayerViewController.swift <==
//
//  ViewController.swift
//  VideoApp
//
//  Created by Vasil Nunev on 11/07/2017.
//  Copyright © 2017 nunev. All rights reserved.
//

import AVKit
import UIKit
import AVFoundation

class ViewController_AVPlayer_List: UIViewController {
    
     var canales: [String] = []
     var playVideoIndex:Int = 0
    
    private var index:Int = 0
    private var player: AVQueuePlayer?
    private var queuePlayer: AVPlayerLayer?
    private var isPlayed = true
    private var frameQueuePlayer:CGRect?
    private var frameView:CGRect?
    private  var btnNext = UIButton()
    private  var btnPause = UIButton()
    private  var btnPreview = UIButton()
    private  var btnClose = UIButton()
    private  var activityView :  UIActivityIndicatorView?
    private var isLandscapeLeft : UIInterfaceOrientation = .landscapeLeft
    
    
    
    
    
    //MARK: eventos del ciclo de vida del controlador
    override func viewDidAppear(_ animated: Bool) {
        super.viewDidAppear(animated)
    }
    override func viewWillTransition(to size: CGSize, with coordinator: UIViewControllerTransitionCoordinator) {
        super.viewWillTransition(to: size, with: coordinator)
        if UIDevice.current.orientation.isLandscape {
          
            
            print("Landscape")
            self.queuePlayer?.videoGravity = AVLayerVideoGravity.resizeAspectFill
            
            //  self.queuePlayer?.frame = CGRect(x: 0, y: 0, width: 700, height:375)
            
            self.queuePlayer?.frame = self.frameQueuePlayer!
        } else {
            print("Portrait")
            // self.queuePlayer?.frame = CGRect(x: 0, y: 0, width: 380, height:200)
            self.queuePlayer?.frame = self.frameQueuePlayer!
            self.view.frame  = self.frameView!
            //self.view.frame = CGRect(x:0, y: 200, width: (self.view.frame.size.height), height: (self.view.frame.size.width))
        }
    }
    override func viewDidLoad() {
        super.viewDidLoad()
        self.navigationController?.setNavigationBarHidden(true, animated: true)
        self.navigationController?.setToolbarHidden(true, animated: true)
        let value = UIInterfaceOrientation.landscapeLeft.rawValue
        UIDevice.current.setValue(value, forKey: "orientation")

        self.modalPresentationStyle = .fullScreen
    }
    override func viewWillDisappear(_ animated: Bool) {
        super.viewWillDisappear(animated)
        player?.pause() // 1. pause the player to stop it
        queuePlayer?.player = nil // 2. set the playerLayer's player to nil
        queuePlayer?.removeFromSuperlayer() // 3 remove the playerLayer from it's superLayer
        
    }
    override func viewWillAppear(_ animated: Bool) {
        super.viewWillAppear(animated)
        
       startDemoVideo(canales: self.canales, playVideoIndex : self.playVideoIndex)
        buildButtons()
    }
  
    //MARK: inicializar reproductor con los canales para hacer zapping
    private func startDemoVideo(canales: [String], playVideoIndex : Int) {
        //sortVideosAtIndex(canales: xcanales, index: playVideoIndex)
        
        player = AVQueuePlayer()
        queuePlayer = AVPlayerLayer(player: player)
        
        
        guard let queuePlayer = queuePlayer else { fatalError("Error creating player layer") }
        
        queuePlayer.frame = self.view.bounds
        self.frameQueuePlayer =  queuePlayer.frame
        
        queuePlayer.backgroundColor = UIColor.black.cgColor
        
        //        self.view.frame = CGRect(x: 0, y: 0, width: (self.view.frame.size.height), height: (self.view.frame.size.width))
        
        
        self.frameView =    self.view.frame
        
        self.view.layer.addSublayer(queuePlayer)
        
        
        delayWithSeconds(10) {
            
            self.btnClose.isHidden = true
            self.btnNext.isHidden = true
            self.btnPause.isHidden = true
            self.btnPreview.isHidden = true
        }
        
        
     
                var lastItem = self.player?.items().last
                      let url = URL(string: canales[playVideoIndex])
                    let item = AVPlayerItem(url: url!)
                    self.player?.insert(item, after: lastItem)
                    lastItem = item
               
                DispatchQueue.main.async {
                    self.addObserverPlayerItem()
        
                    self.player?.play()
                }
        
//
//        var lastItem = self.player?.items().last
//        for item in xcanales {
//
//            let url = URL(string: item)
//            let item = AVPlayerItem(url: url!)
//            self.player?.insert(item, after: lastItem)
//            lastItem = item
//        }
//        DispatchQueue.main.async {
//            self.addObserverPlayerItem()
//
//            self.player?.play()
//        }
    }
     
    
    
    
    //MARK: Agregar observadores al reproductor
    private func addObserverPlayerItem(){
    if let playerItem = self.player?.currentItem{
        playerItem.addObserver(self, forKeyPath: "playbackBufferEmpty", options: .new, context: nil)
        playerItem.addObserver(self, forKeyPath: "playbackLikelyToKeepUp", options: .new, context: nil)
        playerItem.addObserver(self, forKeyPath: "playbackBufferFull", options: .new, context: nil)
        playerItem.addObserver(self, forKeyPath: "duration", options: [.new, .initial], context: nil)
        self.player?.addObserver(self, forKeyPath: #keyPath(AVPlayer.currentItem.status), options: [.new, .initial], context: nil)
        self.player?.addObserver(self, forKeyPath: #keyPath(AVPlayer.status), options: [.new, .initial], context: nil)
        
    }
}
    //MARK: resultados de los observadores en el reproductor
    override public func observeValue(forKeyPath keyPath: String?, of object: Any?, change: [NSKeyValueChangeKey : Any]?, context: UnsafeMutableRawPointer?) {
        
        guard let currentItem = self.player!.currentItem else {return}
        
        if object is AVPlayerItem {
            switch keyPath {
            case "duration":
                let interval = CMTime(seconds: 10, preferredTimescale: CMTimeScale(NSEC_PER_SEC))
                let mainQueue = DispatchQueue.main
                _ = self.player!.addPeriodicTimeObserver(forInterval: interval, queue: mainQueue, using: { [weak self] time in
                    
                    print("time "+(self?.getTimeString(from: currentItem.currentTime()))!)
                    
                    // print(currentItem.currentTime())
                })
                
            case "playbackBufferEmpty":
                // Show loader
                self.showActivityIndicatory()
                
            case "playbackLikelyToKeepUp":
                // Hide loader
                self.activityView!.stopAnimating()
                print(" self.activityIndicator?.stopAnimating()")
                
            case "playbackBufferFull":
                // Hide loader
                self.activityView!.stopAnimating()
                print(" self.activityIndicator?.stopAnimating()")
            case #keyPath(AVPlayer.currentItem.status):
                
                let newStatus: AVPlayerItem.Status
                if let newStatusAsNumber = change?[NSKeyValueChangeKey.newKey] as? NSNumber {
                    newStatus = AVPlayerItem.Status(rawValue: newStatusAsNumber.intValue)!
                } else {
                    newStatus = .unknown
                }
                if newStatus == .failed {
                    NSLog("SA Detected Error: \(String(describing: self.player?.currentItem?.error?.localizedDescription)), error: \(String(describing: self.player?.currentItem?.error))")
                }
            case #keyPath(AVPlayer.status):
                print()
            case .none:
                self.activityView!.stopAnimating()
                print(" self.activityIndicator?.stopAnimating()")
            case .some(_):
                self.activityView!.stopAnimating()
                print(" self.activityIndicator?.stopAnimating()")
            }
        }
    }
 
    // MARK: construir y dibujar botones en el reproductor
    private func buildButtons() {
        
        btnClose.frame = CGRect(x: (self.view.frame.maxX/10), y: (self.view.frame.maxY/14), width: 70, height: 50)
        btnClose.addTarget(self, action: #selector(closePlayer), for: .touchUpInside)
        btnClose.setTitle("Close", for: .normal)
        
        
        btnPreview.frame = CGRect(x: (self.view.frame.maxX/4.5), y: (self.view.frame.maxY/2.5), width: 70, height: 50)
        btnPreview.addTarget(self, action: #selector(previewVideo), for: .touchUpInside)
        btnPreview.setTitle("Preview", for: .normal)
        
        
        btnPause.frame = CGRect(x: (self.view.frame.maxX/2), y: (self.view.frame.maxY/2.5), width: 50, height: 50)
        btnPause.addTarget(self, action: #selector(PauseVideo), for: .touchUpInside)
        btnPause.setTitle("Pause", for: .normal)
        
        
        btnNext.frame = CGRect(x: (self.view.frame.maxX/1.3),  y: (self.view.frame.maxY/2.5), width: 50, height: 50)
        btnNext.addTarget(self, action: #selector(nextVideo), for: .touchUpInside)
        btnNext.setTitle("Next", for: .normal)
        
        let gesture = UITapGestureRecognizer(target: self, action:  #selector(self.checkAction))
        
        self.view.addGestureRecognizer(gesture)
        self.view.addSubview(btnNext)
        self.view.addSubview(btnPause)
        self.view.addSubview(btnPreview)
        self.view.addSubview(btnClose)
        
//                let frame = CGRect(x: 50, y: 80, width: 100, height: 50)
//                      let routePickerView = AVRoutePickerView(frame: frame)
//                         routePickerView.backgroundColor = UIColor.clear
//                         view.addSubview(routePickerView)
//                         let label = UILabel(frame: routePickerView.bounds)
//                         label.textColor = .white
//                         routePickerView.addSubview(label)
//                         label.text = "Airplay"
//        
//        
        
    }
    
    // MARK: metodos de botones del reproductor
    @objc func checkAction(sender : UITapGestureRecognizer) {
        print("touch view gesture")
        
        self.btnClose.isHidden = false
        self.btnNext.isHidden = false
        self.btnPause.isHidden = false
        self.btnPreview.isHidden = false
        
        delayWithSeconds(7) {
            
            self.btnClose.isHidden = true
            self.btnNext.isHidden = true
            self.btnPause.isHidden = true
            self.btnPreview.isHidden = true
        }
    }
    @objc func nextVideo(sender: UIButton!) {
      //    self.player?.advanceToNextItem()
        index+=1
        if(index == canales.count){
            index=0

            player?.removeAllItems()
            let url = URL(string : canales[index])
            let playerItem = AVPlayerItem.init(url: url!)
            player?.insert(playerItem, after: nil)
        }else{

            player?.removeAllItems()
            let url = URL(string : canales[index])
            let playerItem = AVPlayerItem.init(url: url!)
            player?.insert(playerItem, after: nil)

        }
    }
    @objc  func PauseVideo(_ sender: UIButton) {
        if isPlayed {
            player?.pause()
            isPlayed = false
            (sender as AnyObject).setTitle("Play", for: .normal)
        }else{
            player?.play()
            isPlayed = true
            (sender as AnyObject).setTitle("Pause", for: .normal)
        }
    }
    @objc func previewVideo(_ sender: UIButton) {
        
        if(index == 0){
            index=canales.count
        }
        index-=1
        player?.removeAllItems()
        let item =   canales[index]
        let url = URL(string: item)
        let playerItem = AVPlayerItem(url: url!)
        player?.insert(playerItem, after: nil)
        
        
    }
    @objc func closePlayer(_ sender: UIButton) {
        print("closePlayer")
        self.dismiss(animated: true, completion: nil)
        let value = UIInterfaceOrientation.portrait.rawValue
        UIDevice.current.setValue(value, forKey: "orientation")
        
    }

   // MARK: para detectar cambio de pantalla y establecer landscape left o right
    override func willRotate(to toInterfaceOrientation: UIInterfaceOrientation, duration: TimeInterval) {

                  var text=""
               switch UIDevice.current.orientation{
               case .portrait:
                   text="Portrait"
               case .portraitUpsideDown:
                   text="PortraitUpsideDown"
               case .landscapeLeft:
                   text="LandscapeLeft"
               case .landscapeRight:
                   text="LandscapeRight"
               default:
                   text="Another"
               }
               print("You have moved1: \(text)")
      
       }
    override func didRotate(from fromInterfaceOrientation: UIInterfaceOrientation) {
           var text=""
           switch UIDevice.current.orientation{
           case .portrait:
               text="Portrait"
           case .portraitUpsideDown:
               text="PortraitUpsideDown"
           case .landscapeLeft:
               text="LandscapeLeft"
           case .landscapeRight:
               text="LandscapeRight"
           default:
               text="Another"
           }
           print("You have moved3: \(text)")
       }
//    override public var shouldAutorotate: Bool {
//           return true
//       }
//    override public var supportedInterfaceOrientations: UIInterfaceOrientationMask {
//
//            if UIDevice.current.orientation == .landscapeLeft{
//
//                          print("landscapeLeft3")
//                           self.isLandscapeLeft = .landscapeLeft
//                      }
//                      else  if UIDevice.current.orientation == .landscapeRight{
//                          self.isLandscapeLeft = .landscapeRight
//
//           print("landscapeLeft333")
//
//                      }
//
//           let orientation: UIInterfaceOrientationMask = [UIInterfaceOrientationMask.landscape, UIInterfaceOrientationMask.landscapeRight]
//              return orientation
//       }
//    override public var preferredInterfaceOrientationForPresentation: UIInterfaceOrientation {
//
//           return   self.isLandscapeLeft  ;
//       }
    
    // MARK: Utilidades
    
    private func sortVideosAtIndex(canales: [String], index : Int) {
           var tempArrayCanales: [String] = []
        
        for i in index..<canales.count {
            tempArrayCanales.append(canales[i])
        }
        for i in 0..<index {
            tempArrayCanales.append(canales[i])
        }
        print("tempArrayCanales")
        print(tempArrayCanales)
        print("  self.canales")
        print(  self.canales)
       
        self.canales = tempArrayCanales;
    }
    
    private func getTimeString(from time: CMTime) -> String {
        let totalSeconds = CMTimeGetSeconds(time)
        let hours = Int(totalSeconds/3600)
        let minutes = Int(totalSeconds/60) % 60
        let seconds = Int(totalSeconds.truncatingRemainder(dividingBy: 60))
        if hours > 0 {
            return String(format: "%i:%02i:%02i", arguments: [hours,minutes,seconds])
        }else {
            return String(format: "%02i:%02i", arguments: [minutes,seconds])
        }
    }
    private func delayWithSeconds(_ seconds: Double, completion: @escaping () -> ()) {
        DispatchQueue.main.asyncAfter(deadline: .now() + seconds) {
            completion()
        }
    }
    private func showActivityIndicatory() {
        let container: UIView = UIView()
        container.frame = CGRect(x: 0, y: 0, width: 80, height: 80) // Set X and Y whatever you want
        container.backgroundColor = .clear
        
        self.activityView = UIActivityIndicatorView(style: .whiteLarge)
        self.activityView?.center = self.view.center
        
        container.addSubview(self.activityView!)
        self.view.addSubview(container)
        self.activityView!.startAnimating()
    }
}

==> hls_player-1.0.6.tar.gz: ios/Classes/CustomAVPlayerViewController.swift <==
//
//  ViewController.swift
//  VideoApp
//
//  Created by Vasil Nunev on 11/07/2017.
//  Copyright © 2017 nunev. All rights reserved.
//

import AVKit
import UIKit
import AVFoundation

class ViewController_AVPlayer_List: UIViewController {
    
     var canales: [String] = []
     var playVideoIndex:Int = 0
    
    private var index:Int = 0
    private var player: AVQueuePlayer?
    private var queuePlayer: AVPlayerLayer?
    private var isPlayed = true
    private var frameQueuePlayer:CGRect?
    private var frameView:CGRect?
    private  var btnNext = UIButton()
    private  var btnPause = UIButton()
    private  var btnPreview = UIButton()
    private  var btnClose = UIButton()
   // private  var  routePickerView = AVRoutePickerView()
    private  var activityView :  UIActivityIndicatorView?
    private var isLandscapeLeft : UIInterfaceOrientation = .landscapeLeft
    
    
    
    
    
    //MARK: eventos del ciclo de vida del controlador
    override func viewDidAppear(_ animated: Bool) {
        super.viewDidAppear(animated)
    }
    override func viewWillTransition(to size: CGSize, with coordinator: UIViewControllerTransitionCoordinator) {
        super.viewWillTransition(to: size, with: coordinator)
        if UIDevice.current.orientation.isLandscape {
          
            
            print("Landscape")
            self.queuePlayer?.videoGravity = AVLayerVideoGravity.resizeAspectFill
            
            //  self.queuePlayer?.frame = CGRect(x: 0, y: 0, width: 700, height:375)
            
            self.queuePlayer?.frame = self.frameQueuePlayer!
        } else {
            print("Portrait")
            // self.queuePlayer?.frame = CGRect(x: 0, y: 0, width: 380, height:200)
            self.queuePlayer?.frame = self.frameQueuePlayer!
            self.view.frame  = self.frameView!
            //self.view.frame = CGRect(x:0, y: 200, width: (self.view.frame.size.height), height: (self.view.frame.size.width))
        }
    }
    override func viewDidLoad() {
        super.viewDidLoad()
        self.navigationController?.setNavigationBarHidden(true, animated: true)
        self.navigationController?.setToolbarHidden(true, animated: true)
        let value = UIInterfaceOrientation.landscapeLeft.rawValue
        UIDevice.current.setValue(value, forKey: "orientation")

        self.modalPresentationStyle = .fullScreen
       
    }
    override func viewWillDisappear(_ animated: Bool) {
        super.viewWillDisappear(animated)
        player?.pause() // 1. pause the player to stop it
        queuePlayer?.player = nil // 2. set the playerLayer's player to nil
        queuePlayer?.removeFromSuperlayer() // 3 remove the playerLayer from it's superLayer
        
    }
    override func viewWillAppear(_ animated: Bool) {
        super.viewWillAppear(animated)
        
       startDemoVideo(canales: self.canales, playVideoIndex : self.playVideoIndex)
        buildButtons()
    }
  
    //MARK: inicializar reproductor con los canales para hacer zapping
    private func startDemoVideo(canales: [String], playVideoIndex : Int) {
        //sortVideosAtIndex(canales: xcanales, index: playVideoIndex)
        
        player = AVQueuePlayer()
        queuePlayer = AVPlayerLayer(player: player)
        
        
        guard let queuePlayer = queuePlayer else { fatalError("Error creating player layer") }
        
        queuePlayer.frame = self.view.bounds
        self.frameQueuePlayer =  queuePlayer.frame
        
        queuePlayer.backgroundColor = UIColor.black.cgColor
        
        //        self.view.frame = CGRect(x: 0, y: 0, width: (self.view.frame.size.height), height: (self.view.frame.size.width))
        
        
        self.frameView =    self.view.frame
        
        self.view.layer.addSublayer(queuePlayer)
        
        
        delayWithSeconds(10) {
            
            self.btnClose.isHidden = true
            self.btnNext.isHidden = true
            self.btnPause.isHidden = true
            self.btnPreview.isHidden = true
           // self.routePickerView.isHidden = true
        }
        
        
     
                var lastItem = self.player?.items().last
                      let url = URL(string: canales[playVideoIndex])
                    let item = AVPlayerItem(url: url!)
                    self.player?.insert(item, after: lastItem)
                    lastItem = item
               
                DispatchQueue.main.async {
                    self.addObserverPlayerItem()
        
                    self.player?.play()
                }
        
//
//        var lastItem = self.player?.items().last
//        for item in xcanales {
//
//            let url = URL(string: item)
//            let item = AVPlayerItem(url: url!)
//            self.player?.insert(item, after: lastItem)
//            lastItem = item
//        }
//        DispatchQueue.main.async {
//            self.addObserverPlayerItem()
//
//            self.player?.play()
//        }
    }
     
    
    
    
    //MARK: Agregar observadores al reproductor
    private func addObserverPlayerItem(){
    if let playerItem = self.player?.currentItem{
        playerItem.addObserver(self, forKeyPath: "playbackBufferEmpty", options: .new, context: nil)
        playerItem.addObserver(self, forKeyPath: "playbackLikelyToKeepUp", options: .new, context: nil)
        playerItem.addObserver(self, forKeyPath: "playbackBufferFull", options: .new, context: nil)
        playerItem.addObserver(self, forKeyPath: "duration", options: [.new, .initial], context: nil)
        self.player?.addObserver(self, forKeyPath: #keyPath(AVPlayer.currentItem.status), options: [.new, .initial], context: nil)
        self.player?.addObserver(self, forKeyPath: #keyPath(AVPlayer.status), options: [.new, .initial], context: nil)
        
    }
}
    //MARK: resultados de los observadores en el reproductor
    override public func observeValue(forKeyPath keyPath: String?, of object: Any?, change: [NSKeyValueChangeKey : Any]?, context: UnsafeMutableRawPointer?) {
        
        guard let currentItem = self.player!.currentItem else {return}
        
        if object is AVPlayerItem {
            switch keyPath {
            case "duration":
                let interval = CMTime(seconds: 10, preferredTimescale: CMTimeScale(NSEC_PER_SEC))
                let mainQueue = DispatchQueue.main
                _ = self.player!.addPeriodicTimeObserver(forInterval: interval, queue: mainQueue, using: { [weak self] time in
                    
                    print("time "+(self?.getTimeString(from: currentItem.currentTime()))!)
                    
                    // print(currentItem.currentTime())
                })
                
            case "playbackBufferEmpty":
                // Show loader
                self.showActivityIndicatory()
                
            case "playbackLikelyToKeepUp":
                // Hide loader
                self.activityView!.stopAnimating()
                print(" self.activityIndicator?.stopAnimating()")
                
            case "playbackBufferFull":
                // Hide loader
                self.activityView!.stopAnimating()
                print(" self.activityIndicator?.stopAnimating()")
            case #keyPath(AVPlayer.currentItem.status):
                
                let newStatus: AVPlayerItem.Status
                if let newStatusAsNumber = change?[NSKeyValueChangeKey.newKey] as? NSNumber {
                    newStatus = AVPlayerItem.Status(rawValue: newStatusAsNumber.intValue)!
                } else {
                    newStatus = .unknown
                }
                if newStatus == .failed {
                    NSLog("SA Detected Error: \(String(describing: self.player?.currentItem?.error?.localizedDescription)), error: \(String(describing: self.player?.currentItem?.error))")
                }
            case #keyPath(AVPlayer.status):
                print()
            case .none:
                self.activityView!.stopAnimating()
                print(" self.activityIndicator?.stopAnimating()")
            case .some(_):
                self.activityView!.stopAnimating()
                print(" self.activityIndicator?.stopAnimating()")
            }
        }
    }
 
    // MARK: construir y dibujar botones en el reproductor
    private func buildButtons() {
        
        btnClose.frame = CGRect(x: (self.view.frame.maxX/10), y: (self.view.frame.maxY/14), width: 70, height: 50)
        btnClose.addTarget(self, action: #selector(closePlayer), for: .touchUpInside)
        btnClose.setTitle("Close", for: .normal)
        
        
        //MARK: button airplay
        // let frame = CGRect(x: self.view.frame.maxX/1.2, y: self.view.frame.maxY/10, width: 100, height: 50)
        //  routePickerView = AVRoutePickerView(frame: frame)
        // routePickerView.backgroundColor = UIColor.clear
        // let label = UILabel(frame: routePickerView.bounds)
        // label.textColor = .white
        // routePickerView.addSubview(label)
        // label.text = "Airplay"
       
        
        
        btnPreview.frame = CGRect(x: (self.view.frame.maxX/4.5), y: (self.view.frame.maxY/2.5), width: 70, height: 50)
        btnPreview.addTarget(self, action: #selector(previewVideo), for: .touchUpInside)
        btnPreview.setTitle("Preview", for: .normal)
        
        
        btnPause.frame = CGRect(x: (self.view.frame.maxX/2), y: (self.view.frame.maxY/2.5), width: 50, height: 50)
        btnPause.addTarget(self, action: #selector(PauseVideo), for: .touchUpInside)
        btnPause.setTitle("Pause", for: .normal)
        
        
        btnNext.frame = CGRect(x: (self.view.frame.maxX/1.3),  y: (self.view.frame.maxY/2.5), width: 50, height: 50)
        btnNext.addTarget(self, action: #selector(nextVideo), for: .touchUpInside)
        btnNext.setTitle("Next", for: .normal)
        
        let gesture = UITapGestureRecognizer(target: self, action:  #selector(self.checkAction))
        
        self.view.addGestureRecognizer(gesture)
        self.view.addSubview(btnNext)
        self.view.addSubview(btnPause)
        self.view.addSubview(btnPreview)
        self.view.addSubview(btnClose)
        //self.view.addSubview(routePickerView)
        
    }
    
    // MARK: metodos de botones del reproductor
    @objc func checkAction(sender : UITapGestureRecognizer) {
        print("touch view gesture")
        
        self.btnClose.isHidden = false
        self.btnNext.isHidden = false
        self.btnPause.isHidden = false
        self.btnPreview.isHidden = false
       // self.routePickerView.isHidden = false
        
        
        delayWithSeconds(7) {
            
            self.btnClose.isHidden = true
            self.btnNext.isHidden = true
            self.btnPause.isHidden = true
            self.btnPreview.isHidden = true
           // self.routePickerView.isHidden = true
            
        }
    }
    @objc func nextVideo(sender: UIButton!) {
      //    self.player?.advanceToNextItem()
        index+=1
        if(index == canales.count){
            index=0

            player?.removeAllItems()
            let url = URL(string : canales[index])
            let playerItem = AVPlayerItem.init(url: url!)
            player?.insert(playerItem, after: nil)
        }else{

            player?.removeAllItems()
            let url = URL(string : canales[index])
            let playerItem = AVPlayerItem.init(url: url!)
            player?.insert(playerItem, after: nil)

        }
    }
    @objc  func PauseVideo(_ sender: UIButton) {
        if isPlayed {
            player?.pause()
            isPlayed = false
            (sender as AnyObject).setTitle("Play", for: .normal)
        }else{
            player?.play()
            isPlayed = true
            (sender as AnyObject).setTitle("Pause", for: .normal)
        }
    }
    @objc func previewVideo(_ sender: UIButton) {
        
        if(index == 0){
            index=canales.count
        }
        index-=1
        player?.removeAllItems()
        let item =   canales[index]
        let url = URL(string: item)
        let playerItem = AVPlayerItem(url: url!)
        player?.insert(playerItem, after: nil)
        
        
    }
    @objc func closePlayer(_ sender: UIButton) {
        print("closePlayer")
        self.dismiss(animated: true, completion: nil)
        let value = UIInterfaceOrientation.portrait.rawValue
        UIDevice.current.setValue(value, forKey: "orientation")
        
    }

  public func getCurrentLink() -> String{
        
        let url: URL? = (player?.currentItem?.asset as? AVURLAsset)?.url
        
        return url!.absoluteString
    }
    
   // MARK: para detectar cambio de pantalla y establecer landscape left o right
    override func willRotate(to toInterfaceOrientation: UIInterfaceOrientation, duration: TimeInterval) {

                  var text=""
               switch UIDevice.current.orientation{
               case .portrait:
                   text="Portrait"
               case .portraitUpsideDown:
                   text="PortraitUpsideDown"
               case .landscapeLeft:
                   text="LandscapeLeft"
               case .landscapeRight:
                   text="LandscapeRight"
               default:
                   text="Another"
               }
               print("You have moved1: \(text)")
      
       }
    override func didRotate(from fromInterfaceOrientation: UIInterfaceOrientation) {
           var text=""
           switch UIDevice.current.orientation{
           case .portrait:
               text="Portrait"
           case .portraitUpsideDown:
               text="PortraitUpsideDown"
           case .landscapeLeft:
               text="LandscapeLeft"
           case .landscapeRight:
               text="LandscapeRight"
           default:
               text="Another"
           }
           print("You have moved3: \(text)")
       }
//    override public var shouldAutorotate: Bool {
//           return true
//       }
//    override public var supportedInterfaceOrientations: UIInterfaceOrientationMask {
//
//            if UIDevice.current.orientation == .landscapeLeft{
//
//                          print("landscapeLeft3")
//                           self.isLandscapeLeft = .landscapeLeft
//                      }
//                      else  if UIDevice.current.orientation == .landscapeRight{
//                          self.isLandscapeLeft = .landscapeRight
//
//           print("landscapeLeft333")
//
//                      }
//
//           let orientation: UIInterfaceOrientationMask = [UIInterfaceOrientationMask.landscape, UIInterfaceOrientationMask.landscapeRight]
//              return orientation
//       }
//    override public var preferredInterfaceOrientationForPresentation: UIInterfaceOrientation {
//
//           return   self.isLandscapeLeft  ;
//       }
    
    // MARK: Utilidades
    
 
    
    private func getTimeString(from time: CMTime) -> String {
        let totalSeconds = CMTimeGetSeconds(time)
        let hours = Int(totalSeconds/3600)
        let minutes = Int(totalSeconds/60) % 60
        let seconds = Int(totalSeconds.truncatingRemainder(dividingBy: 60))
        if hours > 0 {
            return String(format: "%i:%02i:%02i", arguments: [hours,minutes,seconds])
        }else {
            return String(format: "%02i:%02i", arguments: [minutes,seconds])
        }
    }
    private func delayWithSeconds(_ seconds: Double, completion: @escaping () -> ()) {
        DispatchQueue.main.asyncAfter(deadline: .now() + seconds) {
            completion()
        }
    }
    private func showActivityIndicatory() {
        let container: UIView = UIView()
        container.frame = CGRect(x: 0, y: 0, width: 80, height: 80) // Set X and Y whatever you want
        container.backgroundColor = .clear
        
        self.activityView = UIActivityIndicatorView(style: .whiteLarge)
        self.activityView?.center = self.view.center
        
        container.addSubview(self.activityView!)
        self.view.addSubview(container)
        self.activityView!.startAnimating()
    }
}
